@@ -26,7 +26,7 @@ has 'last_modified' =>
 
 __PACKAGE__->meta->make_immutable;
 
-sub url {
+sub _url {
     my ($self) = @_;
     my $url
         = $self->cloudfiles->storage_url . '/'
@@ -38,9 +38,9 @@ sub url {
 
 sub head {
     my $self    = shift;
-    my $request = HTTP::Request->new( 'HEAD', $self->url,
+    my $request = HTTP::Request->new( 'HEAD', $self->_url,
         [ 'X-Auth-Token' => $self->cloudfiles->token ] );
-    my $response = $self->cloudfiles->request($request);
+    my $response = $self->cloudfiles->_request($request);
     confess 'Object ' . $self->name . ' not found' if $response->code == 404;
     confess 'Unknown error' if $response->code != 204;
     $self->_set_attributes_from_response($response);
@@ -49,9 +49,9 @@ sub head {
 
 sub get {
     my $self    = shift;
-    my $request = HTTP::Request->new( 'GET', $self->url,
+    my $request = HTTP::Request->new( 'GET', $self->_url,
         [ 'X-Auth-Token' => $self->cloudfiles->token ] );
-    my $response = $self->cloudfiles->request($request);
+    my $response = $self->cloudfiles->_request($request);
     confess 'Object ' . $self->name . ' not found' if $response->code == 404;
     confess 'Unknown error' if $response->code != 200;
     confess 'Data corruption error'
@@ -62,9 +62,9 @@ sub get {
 
 sub get_filename {
     my ( $self, $filename ) = @_;
-    my $request = HTTP::Request->new( 'GET', $self->url,
+    my $request = HTTP::Request->new( 'GET', $self->_url,
         [ 'X-Auth-Token' => $self->cloudfiles->token ] );
-    my $response = $self->cloudfiles->request( $request, $filename );
+    my $response = $self->cloudfiles->_request( $request, $filename );
 
     confess 'Object ' . $self->name . ' not found' if $response->code == 404;
     confess 'Unknown error' if $response->code != 200;
@@ -80,9 +80,9 @@ sub get_filename {
 
 sub delete {
     my $self    = shift;
-    my $request = HTTP::Request->new( 'DELETE', $self->url,
+    my $request = HTTP::Request->new( 'DELETE', $self->_url,
         [ 'X-Auth-Token' => $self->cloudfiles->token ] );
-    my $response = $self->cloudfiles->request($request);
+    my $response = $self->cloudfiles->_request($request);
     confess 'Object ' . $self->name . ' not found' if $response->code == 404;
     confess 'Unknown error' if $response->code != 204;
 }
@@ -94,7 +94,7 @@ sub put {
 
     my $request = HTTP::Request->new(
         'PUT',
-        $self->url,
+        $self->_url,
         [   'X-Auth-Token'   => $self->cloudfiles->token,
             'Content-Length' => length($value),
             'ETag'           => $md5_hex,
@@ -102,7 +102,7 @@ sub put {
         ],
         $value
     );
-    my $response = $self->cloudfiles->request($request);
+    my $response = $self->cloudfiles->_request($request);
     return if $response->code == 204;
     confess 'Missing Content-Length or Content-Type header'
         if $response->code == 412;
@@ -121,7 +121,7 @@ sub put_filename {
 
     my $request = HTTP::Request->new(
         'PUT',
-        $self->url,
+        $self->_url,
         [   'X-Auth-Token'   => $self->cloudfiles->token,
             'Content-Length' => $size,
             'ETag'           => $md5_hex,
@@ -129,7 +129,7 @@ sub put_filename {
         ],
         $self->_content_sub($filename),
     );
-    my $response = $self->cloudfiles->request($request);
+    my $response = $self->cloudfiles->_request($request);
     return if $response->code == 204;
     confess 'Missing Content-Length or Content-Type header'
         if $response->code == 412;
@@ -190,3 +190,125 @@ sub _set_attributes_from_response {
 }
 
 1;
+
+__END__
+
+=head1 NAME
+
+Net::Mosso::CloudFiles::Object - Represent a Cloud Files object
+
+=head1 SYNOPSIS
+
+  # To create a new object
+  my $xxx = $container->object( name => 'XXX' );
+  $xxx->put('this is the value');
+
+  # To create a new object with the contents of a local file
+  my $yyy = $container->object( name => 'YYY', content_type => 'text/plain' );
+  $yyy->put_filename('README');
+
+  # To fetch an object:
+  my $xxx2 = $container->object( name => 'XXX' );
+  my $value = $xxx2->get;
+  say 'has name ' . $xxx2->name;
+  say 'has md5 ' . $xxx2->etag;
+  say 'has size ' . $xxx2->size;
+  say 'has content type ' . $xxx2->content_type;
+  say 'has last_modified ' . $xxx2->last_modified;
+
+  # To download an object to a local file
+  $yyy->get_filename('README.downloaded');
+
+=head1 DESCRIPTION
+
+This class represents an object in Cloud Files. It is created by
+calling object or objects on a L<Net::Mosso::CloudFiles::Container> object.
+
+=head1 METHODS
+
+=head2 name
+
+Returns the name of the object.
+
+  say 'has name ' . $object->name;
+
+=head2 head
+
+Fetches the metadata of the object:
+
+  $object->head;
+
+=head2 get
+
+Fetches the metadata and content of an object:
+
+  my $value = $object->get;
+
+=head2 get_filename
+
+Downloads the content of an object to a local file,
+checks the integrity of the file, sets metadata in the object
+and sets the last modified time of the file to the same as the object.
+
+  $object->get_filename('README.downloaded');
+
+=head2 delete
+
+Deletes an object:
+
+  $object->delete;
+
+=head2 put
+
+Creates a new object:
+
+  my $xxx = $container->object( name => 'XXX' );
+  $xxx->put('this is the value');
+
+=head2 put_filename
+
+Creates a new object with the contents of a local file:
+
+  my $yyy = $container->object( name => 'YYY', content_type => 'text/plain' );
+  $yyy->put_filename('README');
+
+=head2 etag
+
+Returns the entity tag of the object, which is its MD5:
+
+  say 'has md5 ' . $object->etag;
+
+=head2 size
+
+Return the size of an object in bytes:
+
+  say 'has size ' . $object->size;
+
+=head2 content_type
+
+Return the content type of an object:
+
+  say 'has content type ' . $object->content_type;
+
+=head2 last_modified
+
+Return the last modified time of an object as a L<DateTime> object:
+
+  say 'has last_modified ' . $object->last_modified;
+
+=head1 SEE ALSO
+
+L<Net::Mosso::CloudFiles>, L<Net::Mosso::CloudFiles::Container>.
+
+=head1 AUTHOR
+
+Leon Brocard <acme@astray.com>.
+
+=head1 COPYRIGHT
+
+Copyright (C) 2008-9, Leon Brocard
+
+=head1 LICENSE
+
+This module is free software; you can redistribute it or modify it
+under the same terms as Perl itself.
